"""Generated model names for cohere provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 7
"""

from __future__ import annotations

from typing import Literal


CohereModels = Literal[
    "cohere:command-a-03-2025",
    "cohere:command-a-reasoning-08-2025",
    "cohere:command-a-translate-08-2025",
    "cohere:command-a-vision-07-2025",
    "cohere:command-r-08-2024",
    "cohere:command-r-plus-08-2024",
    "cohere:command-r7b-12-2024",
]

__all__ = ["CohereModels"]
